Bifrost: Class Hierarchy

Bifrost

Class Hierarchy
This inheritance list is sorted roughly, but not completely, alphabetically:
[detail level 12]

C BackwardCDBG< Unitig_data_t, Graph_data_t, is_const > | Wrapper for class neighborIterator to iterate over the predecessors of a reference unitig used in a UnitigMap object
C CCDBG_Data_t< Unitig_data_t > | If data are to be associated with the unitigs of the colored and compacted de Bruijn graph, those data must be wrapped into a class that inherits from the abstract class CCDBG_Data_t
▼C CDBG_Build_opt | Most members of this structure are parameters for CompactedDBG<U, G>::build(), except for:
C CCDBG_Build_opt | This structure inherits from CDBG_Build_opt and introduces only a few new members which are color-related
C CDBG_Data_t< Unitig_data_t, Graph_data_t > | If data are to be associated with the unitigs of the compacted de Bruijn graph, those data must be wrapped into a class that inherits from the abstract class CDBG_Data_t
▼C CDBG_Data_t< DataAccessor< Unitig_data_t >, DataStorage< Unitig_data_t > > |
C DataAccessor< Unitig_data_t > | Interface to access the colors and the data associated with a unitig of a ColoredCDBG
C CompactedDBG< Unitig_data_t, Graph_data_t > | Represent a Compacted de Bruijn graph
▼C CompactedDBG< DataAccessor< Unitig_data_t >, DataStorage< Unitig_data_t > > |
C ColoredCDBG< Unitig_data_t > | Represent a Colored and Compacted de Bruijn graph
C DataStorage< Unitig_data_t > |
C ForwardCDBG< Unitig_data_t, Graph_data_t, is_const > | Wrapper for class neighborIterator to iterate over the predecessors of a reference unitig used in a UnitigMap object
▼Citerator |
C neighborIterator< Unitig_data_t, Graph_data_t, is_const > | Iterator for the neighbors (predecessors or successors) of a reference unitig used in a UnitigMap object
C UnitigColors::UnitigColors_const_iterator | See UnitigColors::const_iterator
C unitigIterator< Unitig_data_t, Graph_data_t, is_const > | Iterator for the unitigs of a Compacted de Bruijn graph
C Kmer | Interface to store and manipulate k-mers
C KmerHash |
C Unitig< T > | Represent a unitig which is a vertex of the Compacted de Bruijn graph
C UnitigColors | Represent the k-mer color sets of a unitig
C UnitigColorsHash |
▼C UnitigMapBase | Structure containing the basic information of a unitig mapping
C UnitigMap< Unitig_data_t, Graph_data_t, is_const > | Contain all the information for the mapping of a k-mer or a sequence to a unitig of a Compacted de Bruijn graph
C UnitigMap< U, G, is_const > |
C UnitigMapHash< Unitig_data_t, Graph_data_t, is_const > |